==> haskell-snap-core-1.0.4.2-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 snap-core
version:              1.0.4.2
visibility:           public
id:                   snap-core-1.0.4.2-JfPnRPBKYreBE6647f8qed
key:                  snap-core-1.0.4.2-JfPnRPBKYreBE6647f8qed
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    This library contains the core definitions and types for the Snap framework,
    including:

    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)

    2. A monad for programming web handlers called \"Snap\", which allows:

    * Stateful access to the HTTP request and response objects

    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together

    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing

    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".

category:             Web, Snap, IO-Streams
abi:                  3feb69b54459efd952db67a68f009aa6
exposed:              True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy

hidden-modules:
    Snap.Internal.Instances Snap.Internal.Routing
    Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
    Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads

import-dirs:          /usr/lib/ghc-8.10.2/site-local/snap-core-1.0.4.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/snap-core-1.0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/snap-core-1.0.4.2
hs-libraries:         HSsnap-core-1.0.4.2-JfPnRPBKYreBE6647f8qed
depends:
    HUnit-1.6.0.0-22oxvb8RM9BHmeY4GS3R8r
    attoparsec-0.13.2.4-8ozNPIXXMcDHzUghDR61gU base-4.14.1.0
    bytestring-0.10.10.0
    case-insensitive-1.2.1.0-JyDtjOlIWzSBSwCZsM9Mt7 containers-0.6.2.1
    directory-1.3.6.0 filepath-1.4.2.1
    hashable-1.3.0.0-JGLlBEJENIuAu5I6ebR7jm
    io-streams-1.5.1.0-Jv8jUbHKE5w6N1CO91hMgK
    lifted-base-0.2.3.12-7qXjOOhOKseKGf8zmVNHgP
    monad-control-1.0.2.3-8y9R5MrVeGDlsyvCtuovd mtl-2.2.2
    network-3.1.2.0-F7RvimuUXfr8J8mPq0Fg6c
    network-uri-2.6.3.0-61P6BJ4psX64KMmEkAEQRu
    old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    random-1.1-IcUwfYF3CGOHS82o6ktbLi
    readable-0.3.1-2woGQEAELxWFVGTY1YAten
    regex-posix-0.96.0.0-5IU8rsGwB0AIcdeVIFfdse text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2
    transformers-base-0.4.5.2-CjQNf7cAS4OKmJApB9SWyv
    unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP
    unordered-containers-0.2.12.0-32hypcNpCYxF7nyZEjDl6X
    vector-0.12.1.2-1NVIFdUJ04d5LWJjqOrbRq

haddock-interfaces:   /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html:         /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-core-1.0.4.2-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 snap-core
version:              1.0.4.2
visibility:           public
id:                   snap-core-1.0.4.2-2lr44IAX17dCsw8cLWHibs
key:                  snap-core-1.0.4.2-2lr44IAX17dCsw8cLWHibs
license:              BSD-3-Clause
maintainer:           snap@snapframework.com
author:               Snap Framework Authors (see CONTRIBUTORS)
homepage:             http://snapframework.com/
synopsis:             Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.

    This library contains the core definitions and types for the Snap framework,
    including:

    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)

    2. A monad for programming web handlers called \"Snap\", which allows:

    * Stateful access to the HTTP request and response objects

    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together

    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing

    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".

category:             Web, Snap, IO-Streams
abi:                  d552d58aae16fbfc23dc12ddba73b5a9
exposed:              True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy

hidden-modules:
    Snap.Internal.Instances Snap.Internal.Routing
    Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
    Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads

import-dirs:          /usr/lib/ghc-8.10.2/site-local/snap-core-1.0.4.2
library-dirs:         /usr/lib/ghc-8.10.2/site-local/snap-core-1.0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/snap-core-1.0.4.2
hs-libraries:         HSsnap-core-1.0.4.2-2lr44IAX17dCsw8cLWHibs
depends:
    HUnit-1.6.0.0-22oxvb8RM9BHmeY4GS3R8r
    attoparsec-0.13.2.4-8ozNPIXXMcDHzUghDR61gU base-4.14.1.0
    bytestring-0.10.10.0
    case-insensitive-1.2.1.0-JyDtjOlIWzSBSwCZsM9Mt7 containers-0.6.2.1
    directory-1.3.6.0 filepath-1.4.2.1
    hashable-1.3.0.0-JGLlBEJENIuAu5I6ebR7jm
    io-streams-1.5.1.0-Jv8jUbHKE5w6N1CO91hMgK
    lifted-base-0.2.3.12-7qXjOOhOKseKGf8zmVNHgP
    monad-control-1.0.2.3-8y9R5MrVeGDlsyvCtuovd mtl-2.2.2
    network-3.1.2.0-F7RvimuUXfr8J8mPq0Fg6c
    network-uri-2.6.3.0-6huqpvjP5AA7URohCDVsI5
    old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    random-1.1-IcUwfYF3CGOHS82o6ktbLi
    readable-0.3.1-2woGQEAELxWFVGTY1YAten
    regex-posix-0.96.0.0-5IU8rsGwB0AIcdeVIFfdse text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2
    transformers-base-0.4.5.2-CjQNf7cAS4OKmJApB9SWyv
    unix-compat-0.5.2-7IcOHcLTxJI58jp45CNrGP
    unordered-containers-0.2.12.0-32hypcNpCYxF7nyZEjDl6X
    vector-0.12.1.2-1NVIFdUJ04d5LWJjqOrbRq

haddock-interfaces:   /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html:         /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
